function varargout = numberReformatter(varargin)
% NUMBERREFORMATTER M-file for numberReformatter.fig
%      
% This script demonstrates the use of edit controls for numeric input 
% and using handles properties of data (state) storage. See my my Number
% Reformatter Example Document file for more information.
%
% Created by Dr. C. S. Tritt
% Last Revised: 1/24/07
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help numberReformatter

% Last Modified by GUIDE v2.5 19-Jan-2007 09:40:36

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @numberReformatter_OpeningFcn, ...
                   'gui_OutputFcn',  @numberReformatter_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before numberReformatter is made visible.
function numberReformatter_OpeningFcn(hObject, eventdata, handles, ...
   varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to numberReformatter (see VARARGIN)

% Choose default command line output for numberReformatter
handles.output = hObject;

% Create handles property for value storage.
handles.NumberValue = 0.0;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes numberReformatter wait for user response (see UIRESUME)
% uiwait(handles.figure1);

% --- Outputs from this function are returned to the command line.
function varargout = numberReformatter_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

function numberEdit_Callback(hObject, eventdata, handles)
% hObject    handle to numberEdit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of numberEdit as text
%        str2double(get(hObject,'String')) returns contents of 
%        numberEdit as a double

curValue = str2double(get(hObject,'String'));
curString = sprintf('%f', curValue);
set(hObject, 'String', curString);

% --- Executes during object creation, after setting all properties.
function numberEdit_CreateFcn(hObject, eventdata, handles)
% hObject    handle to numberEdit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns 
% called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor', ...
       get(0,'defaultUicontrolBackgroundColor'));
end